@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2023
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -30,122 +30,117 @@
 
     You should have received a copy of the GNU Lesser General Public License, Apache
     License, and the MIT License along with JSXGraph. If not, see
-    <http://www.gnu.org/licenses/>, <https://www.apache.org/licenses/LICENSE-2.0.html>,
-    and <http://opensource.org/licenses/MIT/>.
+    <https://www.gnu.org/licenses/>, <https://www.apache.org/licenses/LICENSE-2.0.html>,
+    and <https://opensource.org/licenses/MIT/>.
 
  */
 
 /*global JXG: true, define: true, jQuery: true, window: true, document: true, navigator: true, require: true, module: true, console: true */
 /*jslint nomen:true, plusplus:true, forin:true*/
 
-/* depends:
- */
-
 /**
  * @fileoverview The JSXGraph object is defined in this file. JXG.JSXGraph controls all boards.
  * It has methods to create, save, load and free boards. Additionally some helper functions are
  * defined in this file directly in the JXG namespace.
  */
 
-define([], function () {
+/**
+ * JXG is the top object of JSXGraph and defines the namespace
+ * @exports jxg as JXG
+ */
+var jxg = {};
 
-    'use strict';
+// Make sure JXG.extend is not defined
+// If jsxgraph is loaded via loadjsxgraph.js, this is required, but JXG.extend will be undefined
+// If jsxgraph is compiled as an amd module, it is possible that another jsxgraph version is already loaded and we
+// therefore must not re-use the global JXG variable. But in this case JXG.extend will already be defined.
+// This is the reason for this check.
+if (typeof JXG === "object" && !JXG.extend) {
+    jxg = JXG;
+}
 
-    /**
-     * JXG is the top object of JSXGraph and defines the namespace
-     * @exports jxg as JXG
-     */
-    var jxg = {};
+// We need the following two methods "extend" and "shortcut" to create the JXG object via JXG.extend.
 
-    // Make sure JXG.extend is not defined
-    // If jsxgraph is loaded via loadjsxgraph.js, this is required, but JXG.extend will be undefined
-    // If jsxgraph is compiled as an amd module, it is possible that another jsxgraph version is already loaded and we
-    // therefore must not re-use the global JXG variable. But in this case JXG.extend will already be defined.
-    // This is the reason for this check.
-    if (typeof JXG === 'object' && !JXG.extend) {
-        jxg = JXG;
+/**
+ * Copy all properties of the <tt>extension</tt> object to <tt>object</tt>.
+ * @param {Object} object
+ * @param {Object} extension
+ * @param {Boolean} [onlyOwn=false] Only consider properties that belong to extension itself, not any inherited properties.
+ * @param {Boolean} [toLower=false] If true the keys are convert to lower case. This is needed for visProp, see JXG#copyAttributes
+ */
+jxg.extend = function (object, extension, onlyOwn, toLower) {
+    var e, e2;
+
+    onlyOwn = onlyOwn || false;
+    toLower = toLower || false;
+
+    // the purpose of this for...in loop is indeed to use hasOwnProperty only if the caller
+    // explicitly wishes so.
+    for (e in extension) {
+        if (!onlyOwn || (onlyOwn && extension.hasOwnProperty(e))) {
+            if (toLower) {
+                e2 = e.toLowerCase();
+            } else {
+                e2 = e;
+            }
+
+            object[e2] = extension[e];
+        }
+    }
+};
+
+/**
+ * Set a constant <tt>name</tt> in <tt>object</tt> to <tt>value</tt>. The value can't be changed after declaration.
+ * @param {Object} object
+ * @param {String} name
+ * @param {Number|String|Boolean} value
+ * @param {Boolean} ignoreRedefine This should be left at its default: false.
+ */
+jxg.defineConstant = function (object, name, value, ignoreRedefine) {
+    ignoreRedefine = ignoreRedefine || false;
+
+    if (ignoreRedefine && jxg.exists(object[name])) {
+        return;
     }
 
-    // We need the following two methods "extend" and "shortcut" to create the JXG object via JXG.extend.
+    Object.defineProperty(object, name, {
+        value: value,
+        writable: false,
+        enumerable: true,
+        configurable: false
+    });
+};
 
-    /**
-     * Copy all properties of the <tt>extension</tt> object to <tt>object</tt>.
-     * @param {Object} object
-     * @param {Object} extension
-     * @param {Boolean} [onlyOwn=false] Only consider properties that belong to extension itself, not any inherited properties.
-     * @param {Boolean} [toLower=false] If true the keys are convert to lower case. This is needed for visProp, see JXG#copyAttributes
-     */
-    jxg.extend = function (object, extension, onlyOwn, toLower) {
-        var e, e2;
+/**
+ * Copy all properties of the <tt>constants</tt> object in <tt>object</tt> as a constant.
+ * @param {Object} object
+ * @param {Object} constants
+ * @param {Boolean} [onlyOwn=false] Only consider properties that belong to extension itself, not any inherited properties.
+ * @param {Boolean} [toUpper=false] If true the keys are convert to lower case. This is needed for visProp, see JXG#copyAttributes
+ */
+jxg.extendConstants = function (object, constants, onlyOwn, toUpper) {
+    var e, e2;
 
-        onlyOwn = onlyOwn || false;
-        toLower = toLower || false;
+    onlyOwn = onlyOwn || false;
+    toUpper = toUpper || false;
 
-        // the purpose of this for...in loop is indeed to use hasOwnProperty only if the caller
-        // explicitly wishes so.
-        for (e in extension) {
-            if (!onlyOwn || (onlyOwn && extension.hasOwnProperty(e))) {
-                if (toLower) {
-                    e2 = e.toLowerCase();
-                } else {
-                    e2 = e;
-                }
-
-                object[e2] = extension[e];
+    // The purpose of this for...in loop is indeed to use hasOwnProperty only if the caller explicitly wishes so.
+    for (e in constants) {
+        if (!onlyOwn || (onlyOwn && constants.hasOwnProperty(e))) {
+            if (toUpper) {
+                e2 = e.toUpperCase();
+            } else {
+                e2 = e;
             }
+
+            this.defineConstant(object, e2, constants[e]);
         }
-    };
+    }
+};
 
-    /**
-     * Set a constant <tt>name</tt> in <tt>object</tt> to <tt>value</tt>. The value can't be changed after declaration.
-     * @param {Object} object
-     * @param {String} name
-     * @param {Number|String|Boolean} value
-     * @param {Boolean} ignoreRedefine This should be left at its default: false.
-     */
-    jxg.defineConstant = function (object, name, value, ignoreRedefine) {
-        ignoreRedefine = ignoreRedefine || false;
-
-        if (ignoreRedefine && jxg.exists(object[name])) {
-            return;
-        }
-
-        Object.defineProperty(object, name, {
-            value: value,
-            writable: false,
-            enumerable: true,
-            configurable: false,
-        });
-    };
-
-    /**
-     * Copy all properties of the <tt>constants</tt> object in <tt>object</tt> as a constant.
-     * @param {Object} object
-     * @param {Object} constants
-     * @param {Boolean} [onlyOwn=false] Only consider properties that belong to extension itself, not any inherited properties.
-     * @param {Boolean} [toUpper=false] If true the keys are convert to lower case. This is needed for visProp, see JXG#copyAttributes
-     */
-    jxg.extendConstants = function (object, constants, onlyOwn, toUpper) {
-        var e, e2;
-
-        onlyOwn = onlyOwn || false;
-        toUpper = toUpper || false;
-
-        // The purpose of this for...in loop is indeed to use hasOwnProperty only if the caller explicitly wishes so.
-        for (e in constants) {
-            if (!onlyOwn || (onlyOwn && constants.hasOwnProperty(e))) {
-                if (toUpper) {
-                    e2 = e.toUpperCase();
-                } else {
-                    e2 = e;
-                }
-
-                this.defineConstant(object, e2, constants[e]);
-            }
-        }
-    };
-
-    jxg.extend(jxg, /** @lends JXG */ {
+jxg.extend(
+    jxg,
+    /** @lends JXG */ {
         /**
          * Store a reference to every board in this central list. This will at some point
          * replace JXG.JSXGraph.boards.
@@ -192,7 +187,7 @@ define([], function () {
             for (i = 0; i < ext.length; i++) {
                 e = ext[i].toLowerCase();
 
-                if (typeof this.readers[e] !== 'function') {
+                if (typeof this.readers[e] !== "function") {
                     this.readers[e] = reader;
                 }
             }
@@ -220,7 +215,7 @@ define([], function () {
          * @deprecated Use {@link JXG.Board#select}
          */
         getRef: function (board, s) {
-            jxg.deprecated('JXG.getRef()', 'Board.select()');
+            jxg.deprecated("JXG.getRef()", "Board.select()");
             return board.select(s);
         },
 
@@ -229,7 +224,7 @@ define([], function () {
          * @deprecated Use {@link JXG.Board#select}.
          */
         getReference: function (board, s) {
-            jxg.deprecated('JXG.getReference()', 'Board.select()');
+            jxg.deprecated("JXG.getReference()", "Board.select()");
             return board.select(s);
         },
 
@@ -242,8 +237,7 @@ define([], function () {
         getBoardByContainerId: function (s) {
             var b;
             for (b in JXG.boards) {
-                if (JXG.boards.hasOwnProperty(b) &&
-                    JXG.boards[b].container === s) {
+                if (JXG.boards.hasOwnProperty(b) && JXG.boards[b].container === s) {
                     return JXG.boards[b];
                 }
             }
@@ -258,10 +252,10 @@ define([], function () {
          * @param {String} [replacement] The replacement that should be used instead.
          */
         deprecated: function (what, replacement) {
-            var warning = what + ' is deprecated.';
+            var warning = what + " is deprecated.";
 
             if (replacement) {
-                warning += ' Please use ' + replacement + ' instead.';
+                warning += " Please use " + replacement + " instead.";
             }
 
             jxg.warn(warning);
@@ -274,10 +268,10 @@ define([], function () {
          * @param {String} warning The warning text
          */
         warn: function (warning) {
-            if (typeof window === 'object' && window.console && console.warn) {
-                console.warn('WARNING:', warning);
-            } else if (typeof document === 'object' && document.getElementById('warning')) {
-                document.getElementById('debug').innerHTML += 'WARNING: ' + warning + '<br />';
+            if (typeof window === "object" && window.console && console.warn) {
+                console.warn("WARNING:", warning);
+            } else if (typeof document === "object" && document.getElementById("warning")) {
+                document.getElementById("debug").innerHTML += "WARNING: " + warning + "<br />";
             }
         },
 
@@ -292,10 +286,10 @@ define([], function () {
 
             for (i = 0; i < arguments.length; i++) {
                 p = arguments[i];
-                if (typeof window === 'object' && window.console && console.log) {
+                if (typeof window === "object" && window.console && console.log) {
                     console.log(p);
-                } else if (typeof document === 'object' && document.getElementById('debug')) {
-                    document.getElementById('debug').innerHTML += p + '<br/>';
+                } else if (typeof document === "object" && document.getElementById("debug")) {
+                    document.getElementById("debug").innerHTML += p + "<br/>";
                 }
             }
         },
@@ -313,8 +307,8 @@ define([], function () {
             jxg.debugInt.apply(this, arguments);
 
             if (e && e.stack) {
-                jxg.debugInt('stacktrace');
-                jxg.debugInt(e.stack.split('\n').slice(1).join('\n'));
+                jxg.debugInt("stacktrace");
+                jxg.debugInt(e.stack.split("\n").slice(1).join("\n"));
             }
         },
 
@@ -332,7 +326,7 @@ define([], function () {
             jxg.debugInt.apply(this, arguments);
 
             if (e && e.stack) {
-                jxg.debugInt('Called from', e.stack.split('\n').slice(2, 3).join('\n'));
+                jxg.debugInt("Called from", e.stack.split("\n").slice(2, 3).join("\n"));
             }
         },
 
@@ -347,7 +341,7 @@ define([], function () {
         debug: function (s) {
             jxg.debugInt.apply(this, arguments);
         }
-    });
+    }
+);
 
-    return jxg;
-});
+export default jxg;
