@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2023
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -25,86 +25,82 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
 
-
 /*global JXG: true, define: true*/
 /*jslint nomen: true, plusplus: true*/
 
-/* depends:
- jxg
- */
-
 /**
  * @fileoverview A class for complex arithmetics JXG.Complex is defined in this
  * file. Also a namespace JXG.C is included to provide instance-independent
  * arithmetic functions.
  */
 
-define(['jxg', 'utils/type'], function (JXG, Type) {
+import JXG from "../jxg";
+import Type from "../utils/type";
 
-    "use strict";
+/**
+ * Creates a new complex number.
+ * @class This class is for calculating with complex numbers.
+ * @constructor
+ * @param {Number} [x=0] Real part.
+ * @param {Number} [y=0] Imaginary part.
+ */
+JXG.Complex = function (x, y) {
+    /**
+     * This property is only to signalize that this object is of type JXG.Complex. Only
+     * used internally to distinguish between normal JavaScript numbers and JXG.Complex numbers.
+     * @type Boolean
+     * @default true
+     * @private
+     */
+    this.isComplex = true;
+
+    /* is the first argument a complex number? if it is,
+     * extract real and imaginary part. */
+    if (x && x.isComplex) {
+        y = x.imaginary;
+        x = x.real;
+    }
 
     /**
-     * Creates a new complex number.
-     * @class This class is for calculating with complex numbers.
-     * @constructor
-     * @param {Number} [x=0] Real part.
-     * @param {Number} [y=0] Imaginary part.
+     * Real part of the complex number.
+     * @type Number
+     * @default 0
      */
-    JXG.Complex = function (x, y) {
-        /**
-         * This property is only to signalize that this object is of type JXG.Complex. Only
-         * used internally to distinguish between normal JavaScript numbers and JXG.Complex numbers.
-         * @type Boolean
-         * @default true
-         * @private
-         */
-        this.isComplex = true;
+    this.real = x || 0;
 
-        /* is the first argument a complex number? if it is,
-         * extract real and imaginary part. */
-        if (x && x.isComplex) {
-            y = x.imaginary;
-            x = x.real;
-        }
+    /**
+     * Imaginary part of the complex number.
+     * @type Number
+     * @default 0
+     */
+    this.imaginary = y || 0;
 
-        /**
-         * Real part of the complex number.
-         * @type Number
-         * @default 0
-         */
-        this.real = x || 0;
+    /**
+     * Absolute value in the polar form of the complex number. Currently unused.
+     * @type Number
+     */
+    this.absval = 0;
 
-        /**
-         * Imaginary part of the complex number.
-         * @type Number
-         * @default 0
-         */
-        this.imaginary = y || 0;
+    /**
+     * Angle value in the polar form of the complex number. Currently unused.
+     * @type Number
+     */
+    this.angle = 0;
+};
 
-        /**
-         * Absolute value in the polar form of the complex number. Currently unused.
-         * @type Number
-         */
-        this.absval = 0;
-
-        /**
-         * Angle value in the polar form of the complex number. Currently unused.
-         * @type Number
-         */
-        this.angle = 0;
-    };
-
-    JXG.extend(JXG.Complex.prototype, /** @lends JXG.Complex.prototype */ {
+JXG.extend(
+    JXG.Complex.prototype,
+    /** @lends JXG.Complex.prototype */ {
         /**
          * Converts a complex number into a string.
          * @returns {String} Formatted string containing the complex number in human readable form (algebraic form).
          */
         toString: function () {
-            return this.real + ' + ' + this.imaginary + 'i';
+            return this.real + " + " + this.imaginary + "i";
         },
 
         /**
@@ -184,7 +180,7 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
                 this.imaginary /= c;
             } else {
                 //  (a+ib)(x+iy) = ax-by + i(xb+ay)
-                if ((Math.abs(c.real) < Math.eps) && (Math.abs(c.imaginary) < Math.eps)) {
+                if (Math.abs(c.real) < Math.eps && Math.abs(c.imaginary) < Math.eps) {
                     this.real = Infinity;
                     this.imaginary = Infinity;
 
@@ -211,100 +207,100 @@ define(['jxg', 'utils/type'], function (JXG, Type) {
 
             return this;
         }
-    });
+    }
+);
 
-    /**
-     * @description
-     * JXG.C is the complex number (name)space. It provides functions to calculate with
-     * complex numbers (defined in {@link JXG.Complex}). With this namespace you don't have to modify
-     * your existing complex numbers, e.g. to add two complex numbers:
-     * <pre class="code">   var z1 = new JXG.Complex(1, 0);
-     *    var z2 = new JXG.Complex(0, 1);
-     *    z = JXG.C.add(z1, z1);</pre>
-     * z1 and z2 here remain unmodified. With the object oriented approach above this
-     * section the code would look like:
-     * <pre class="code">   var z1 = new JXG.Complex(1, 0);
-     *    var z2 = new JXG.Complex(0, 1);
-     *    var z = new JXG.Complex(z1);
-     *    z.add(z2);</pre>
-     * @namespace Namespace for the complex number arithmetic functions.
-     */
-    JXG.C = {};
+/**
+ * @description
+ * JXG.C is the complex number (name)space. It provides functions to calculate with
+ * complex numbers (defined in {@link JXG.Complex}). With this namespace you don't have to modify
+ * your existing complex numbers, e.g. to add two complex numbers:
+ * <pre class="code">   var z1 = new JXG.Complex(1, 0);
+ *    var z2 = new JXG.Complex(0, 1);
+ *    z = JXG.C.add(z1, z1);</pre>
+ * z1 and z2 here remain unmodified. With the object oriented approach above this
+ * section the code would look like:
+ * <pre class="code">   var z1 = new JXG.Complex(1, 0);
+ *    var z2 = new JXG.Complex(0, 1);
+ *    var z = new JXG.Complex(z1);
+ *    z.add(z2);</pre>
+ * @namespace Namespace for the complex number arithmetic functions.
+ */
+JXG.C = {};
 
-    /**
-     * Add two (complex) numbers z1 and z2 and return the result as a (complex) number.
-     * @param {JXG.Complex,Number} z1 Summand
-     * @param {JXG.Complex,Number} z2 Summand
-     * @returns {JXG.Complex} A complex number equal to the sum of the given parameters.
-     */
-    JXG.C.add = function (z1, z2) {
-        var z = new JXG.Complex(z1);
-        z.add(z2);
-        return z;
-    };
+/**
+ * Add two (complex) numbers z1 and z2 and return the result as a (complex) number.
+ * @param {JXG.Complex,Number} z1 Summand
+ * @param {JXG.Complex,Number} z2 Summand
+ * @returns {JXG.Complex} A complex number equal to the sum of the given parameters.
+ */
+JXG.C.add = function (z1, z2) {
+    var z = new JXG.Complex(z1);
+    z.add(z2);
+    return z;
+};
 
-    /**
-     * Subtract two (complex) numbers z1 and z2 and return the result as a (complex) number.
-     * @param {JXG.Complex,Number} z1 Minuend
-     * @param {JXG.Complex,Number} z2 Subtrahend
-     * @returns {JXG.Complex} A complex number equal to the difference of the given parameters.
-     */
-    JXG.C.sub = function (z1, z2) {
-        var z = new JXG.Complex(z1);
-        z.sub(z2);
-        return z;
-    };
+/**
+ * Subtract two (complex) numbers z1 and z2 and return the result as a (complex) number.
+ * @param {JXG.Complex,Number} z1 Minuend
+ * @param {JXG.Complex,Number} z2 Subtrahend
+ * @returns {JXG.Complex} A complex number equal to the difference of the given parameters.
+ */
+JXG.C.sub = function (z1, z2) {
+    var z = new JXG.Complex(z1);
+    z.sub(z2);
+    return z;
+};
 
-    /**
-     * Multiply two (complex) numbers z1 and z2 and return the result as a (complex) number.
-     * @param {JXG.Complex,Number} z1 Factor
-     * @param {JXG.Complex,Number} z2 Factor
-     * @returns {JXG.Complex} A complex number equal to the product of the given parameters.
-     */
-    JXG.C.mult = function (z1, z2) {
-        var z = new JXG.Complex(z1);
-        z.mult(z2);
-        return z;
-    };
+/**
+ * Multiply two (complex) numbers z1 and z2 and return the result as a (complex) number.
+ * @param {JXG.Complex,Number} z1 Factor
+ * @param {JXG.Complex,Number} z2 Factor
+ * @returns {JXG.Complex} A complex number equal to the product of the given parameters.
+ */
+JXG.C.mult = function (z1, z2) {
+    var z = new JXG.Complex(z1);
+    z.mult(z2);
+    return z;
+};
 
-    /**
-     * Divide two (complex) numbers z1 and z2 and return the result as a (complex) number.
-     * @param {JXG.Complex,Number} z1 Dividend
-     * @param {JXG.Complex,Number} z2 Divisor
-     * @returns {JXG.Complex} A complex number equal to the quotient of the given parameters.
-     */
-    JXG.C.div = function (z1, z2) {
-        var z = new JXG.Complex(z1);
-        z.div(z2);
-        return z;
-    };
+/**
+ * Divide two (complex) numbers z1 and z2 and return the result as a (complex) number.
+ * @param {JXG.Complex,Number} z1 Dividend
+ * @param {JXG.Complex,Number} z2 Divisor
+ * @returns {JXG.Complex} A complex number equal to the quotient of the given parameters.
+ */
+JXG.C.div = function (z1, z2) {
+    var z = new JXG.Complex(z1);
+    z.div(z2);
+    return z;
+};
 
-    /**
-     * Conjugate a complex number and return the result.
-     * @param {JXG.Complex,Number} z1 Complex number
-     * @returns {JXG.Complex} A complex number equal to the conjugate of the given parameter.
-     */
-    JXG.C.conj = function (z1) {
-        var z = new JXG.Complex(z1);
-        z.conj();
-        return z;
-    };
+/**
+ * Conjugate a complex number and return the result.
+ * @param {JXG.Complex,Number} z1 Complex number
+ * @returns {JXG.Complex} A complex number equal to the conjugate of the given parameter.
+ */
+JXG.C.conj = function (z1) {
+    var z = new JXG.Complex(z1);
+    z.conj();
+    return z;
+};
 
-    /**
-     * Absolute value of a complex number.
-     * @param {JXG.Complex,Number} z1 Complex number
-     * @returns {Number} real number equal to the absolute value of the given parameter.
-     */
-    JXG.C.abs = function (z1) {
-        var z = new JXG.Complex(z1);
+/**
+ * Absolute value of a complex number.
+ * @param {JXG.Complex,Number} z1 Complex number
+ * @returns {Number} real number equal to the absolute value of the given parameter.
+ */
+JXG.C.abs = function (z1) {
+    var z = new JXG.Complex(z1);
 
-        z.conj();
-        z.mult(z1);
+    z.conj();
+    z.mult(z1);
 
-        return Math.sqrt(z.real);
-    };
+    return Math.sqrt(z.real);
+};
 
-    JXG.Complex.C = JXG.C;
+JXG.Complex.C = JXG.C;
 
-    return JXG.Complex;
-});
+export default JXG.Complex;
