@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2023
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -26,18 +26,13 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
 
 /*global JXG: true, define: true, html_sanitize: true*/
 /*jslint nomen: true, plusplus: true*/
 
-/* depends:
- jxg
- base/constants
- */
-
 /**
  * @fileoverview type.js contains several functions to help deal with javascript's weak types.
  * This file mainly consists of detector functions which verify if a variable is or is not of
@@ -45,13 +40,12 @@
  * the type of a variable.
  */
 
-define([
-    'jxg', 'base/constants'
-], function (JXG, Const) {
+import JXG from "../jxg";
+import Const from "../base/constants";
 
-    'use strict';
-
-    JXG.extend(JXG, /** @lends JXG */ {
+JXG.extend(
+    JXG,
+    /** @lends JXG */ {
         /**
          * Checks if the given string is an id within the given board.
          * @param {JXG.Board} board
@@ -59,7 +53,7 @@ define([
          * @returns {Boolean}
          */
         isId: function (board, s) {
-            return (typeof s === 'string') && !!board.objects[s];
+            return typeof s === "string" && !!board.objects[s];
         },
 
         /**
@@ -69,7 +63,7 @@ define([
          * @returns {Boolean}
          */
         isName: function (board, s) {
-            return typeof s === 'string' && !!board.elementsByName[s];
+            return typeof s === "string" && !!board.elementsByName[s];
         },
 
         /**
@@ -79,7 +73,7 @@ define([
          * @returns {Boolean}
          */
         isGroup: function (board, s) {
-            return typeof s === 'string' && !!board.groups[s];
+            return typeof s === "string" && !!board.groups[s];
         },
 
         /**
@@ -88,7 +82,7 @@ define([
          * @returns {Boolean} True, if v is of type string.
          */
         isString: function (v) {
-            return typeof v === 'string';
+            return typeof v === "string";
         },
 
         /**
@@ -97,7 +91,9 @@ define([
          * @returns {Boolean} True, if v is of type number.
          */
         isNumber: function (v) {
-            return typeof v === 'number' || Object.prototype.toString.call(v) === '[Object Number]';
+            return (
+                typeof v === "number" || Object.prototype.toString.call(v) === "[Object Number]"
+            );
         },
 
         /**
@@ -106,7 +102,7 @@ define([
          * @returns {Boolean} True, if v is a function.
          */
         isFunction: function (v) {
-            return typeof v === 'function';
+            return typeof v === "function";
         },
 
         /**
@@ -121,7 +117,11 @@ define([
             if (Array.isArray) {
                 r = Array.isArray(v);
             } else {
-                r = (v !== null && typeof v === 'object' && typeof v.splice === 'function' && typeof v.join === 'function');
+                r =
+                    v !== null &&
+                    typeof v === "object" &&
+                    typeof v.splice === "function" &&
+                    typeof v.join === "function";
             }
 
             return r;
@@ -132,7 +132,18 @@ define([
          * @param v
          */
         isObject: function (v) {
-            return typeof v === 'object' && !this.isArray(v);
+            return typeof v === "object" && !this.isArray(v);
+        },
+
+        /**
+         * Tests if the input variable is a DOM Document or DocumentFragment node
+         * @param v A variable of any type
+         */
+        isDocumentOrFragment: function (v) {
+            return this.isObject(v) && (
+                v.nodeType === 9 || // Node.DOCUMENT_NODE
+                v.nodeType === 11   // Node.DOCUMENT_FRAGMENT_NODE
+            );
         },
 
         /**
@@ -141,16 +152,16 @@ define([
          * @returns {Boolean} True, if v is of type JXG.Point.
          */
         isPoint: function (v) {
-            if (v !== null && typeof v === 'object' && this.exists(v.elementClass)) {
-                return (v.elementClass === Const.OBJECT_CLASS_POINT);
+            if (v !== null && typeof v === "object" && this.exists(v.elementClass)) {
+                return v.elementClass === Const.OBJECT_CLASS_POINT;
             }
 
             return false;
         },
 
         isPoint3D: function (v) {
-            if (v !== null && typeof v === 'object' && this.exists(v.elType)) {
-                return (v.elType === 'point3d');
+            if (v !== null && typeof v === "object" && this.exists(v.elType)) {
+                return v.elType === "point3d";
             }
 
             return false;
@@ -190,8 +201,8 @@ define([
                 if (this.isArray(v) && v.length > 0) {
                     return this.isTransformationOrArray(v[0]);
                 }
-                if (typeof v === 'object') {
-                    return (v.type === Const.OBJECT_TYPE_TRANSFORMATION);
+                if (typeof v === "object") {
+                    return v.type === Const.OBJECT_TYPE_TRANSFORMATION;
                 }
             }
             return false;
@@ -211,7 +222,7 @@ define([
             checkEmptyString = checkEmptyString || false;
 
             if (checkEmptyString) {
-                return result && v !== '';
+                return result && v !== "";
             }
             return result;
         },
@@ -233,7 +244,7 @@ define([
          * @param v {Object|Array}
          * @returns {boolean} True, if v is an empty object or array.
          */
-        isEmpty: function(v) {
+        isEmpty: function (v) {
             return Object.keys(v).length === 0;
         },
 
@@ -261,12 +272,12 @@ define([
                 return true;
             }
 
-            if (typeof s === 'boolean') {
+            if (typeof s === "boolean") {
                 return s;
             }
 
             if (this.isString(s)) {
-                return (s.toLowerCase() === 'true');
+                return s.toLowerCase() === "true";
             }
 
             return false;
@@ -283,15 +294,22 @@ define([
          * to evaluate.
          */
         createEvalFunction: function (board, param, n) {
-            var f = [], i;
+            var f = [], func, i, e,
+                deps = {};
 
             for (i = 0; i < n; i++) {
-                f[i] = JXG.createFunction(param[i], board, '', true);
+                f[i] = JXG.createFunction(param[i], board, "", true);
+                for (e in f[i].deps) {
+                    deps[e] = f[i].deps;
+                }
             }
 
-            return function (k) {
+            func = function (k) {
                 return f[k]();
             };
+            func.deps = deps;
+
+            return func;
         },
 
         /**
@@ -319,17 +337,20 @@ define([
                 f = board.jc.snippet(term, true, variableName, true);
             } else if (this.isFunction(term)) {
                 f = term;
+                f.deps = {};
             } else if (this.isNumber(term)) {
                 /** @ignore */
                 f = function () {
                     return term;
                 };
+                f.deps = {};
             } else if (this.isString(term)) {
                 // In case of string function like fontsize
                 /** @ignore */
                 f = function () {
                     return term;
                 };
+                f.deps = {};
             }
 
             if (f !== null) {
@@ -361,10 +382,13 @@ define([
          * @returns {Array} List of newly created {@link JXG.Point} elements or false if not all returned elements are points.
          */
         providePoints: function (board, parents, attributes, attrClass, attrArray) {
-            var i, j,
+            var i,
+                j,
                 len,
                 lenAttr = 0,
-                points = [], attr, val;
+                points = [],
+                attr,
+                val;
 
             if (!this.isArray(parents)) {
                 parents = [parents];
@@ -380,15 +404,20 @@ define([
             for (i = 0; i < len; ++i) {
                 if (lenAttr > 0) {
                     j = Math.min(i, lenAttr - 1);
-                    attr = this.copyAttributes(attributes, board.options, attrClass, attrArray[j]);
+                    attr = this.copyAttributes(
+                        attributes,
+                        board.options,
+                        attrClass,
+                        attrArray[j]
+                    );
                 }
                 if (this.isArray(parents[i]) && parents[i].length > 1) {
-                    points.push(board.create('point', parents[i], attr));
+                    points.push(board.create("point", parents[i], attr));
                     points[points.length - 1]._is_new = true;
                 } else if (this.isFunction(parents[i])) {
                     val = parents[i]();
-                    if (this.isArray(val) && (val.length > 1)) {
-                        points.push(board.create('point', [parents[i]], attr));
+                    if (this.isArray(val) && val.length > 1) {
+                        points.push(board.create("point", [parents[i]], attr));
                         points[points.length - 1]._is_new = true;
                     }
                 } else {
@@ -424,11 +453,14 @@ define([
          * @param {Array} attrArray List of subtype attributes for the newly created 3D points. The list of subtypes is mapped to the list of new 3D points.
          * @returns {Array} List of newly created {@link JXG.Point3D} elements or false if not all returned elements are 3D points.
          */
-         providePoints3D: function (view, parents, attributes, attrClass, attrArray) {
-            var i, j,
+        providePoints3D: function (view, parents, attributes, attrClass, attrArray) {
+            var i,
+                j,
                 len,
                 lenAttr = 0,
-                points = [], attr, val;
+                points = [],
+                attr,
+                val;
 
             if (!this.isArray(parents)) {
                 parents = [parents];
@@ -444,16 +476,21 @@ define([
             for (i = 0; i < len; ++i) {
                 if (lenAttr > 0) {
                     j = Math.min(i, lenAttr - 1);
-                    attr = this.copyAttributes(attributes, view.board.options, attrClass, attrArray[j]);
+                    attr = this.copyAttributes(
+                        attributes,
+                        view.board.options,
+                        attrClass,
+                        attrArray[j]
+                    );
                 }
 
                 if (this.isArray(parents[i]) && parents[i].length > 1) {
-                    points.push(view.create('point3d', parents[i], attr));
+                    points.push(view.create("point3d", parents[i], attr));
                     points[points.length - 1]._is_new = true;
                 } else if (this.isFunction(parents[i])) {
                     val = parents[i]();
-                    if (this.isArray(val) && (val.length > 1)) {
-                        points.push(view.create('point3d', [parents[i]], attr));
+                    if (this.isArray(val) && val.length > 1) {
+                        points.push(view.create("point3d", [parents[i]], attr));
                         points[points.length - 1]._is_new = true;
                     }
                 } else {
@@ -503,7 +540,8 @@ define([
          * <tt>-1</tt> if the value was not found.
          */
         indexOf: function (array, value, sub) {
-            var i, s = this.exists(sub);
+            var i,
+                s = this.exists(sub);
 
             if (Array.indexOf && !s) {
                 return array.indexOf(value);
@@ -566,7 +604,10 @@ define([
          * @returns {Array}
          */
         uniqueArray: function (arr) {
-            var i, j, isArray, ret = [];
+            var i,
+                j,
+                isArray,
+                ret = [];
 
             if (arr.length === 0) {
                 return [];
@@ -576,14 +617,14 @@ define([
                 isArray = this.isArray(arr[i]);
 
                 if (!this.exists(arr[i])) {
-                    arr[i] = '';
+                    arr[i] = "";
                     continue;
                 }
                 for (j = i + 1; j < arr.length; j++) {
                     if (isArray && JXG.cmpArrays(arr[i], arr[j])) {
                         arr[i] = [];
                     } else if (!isArray && arr[i] === arr[j]) {
-                        arr[i] = '';
+                        arr[i] = "";
                     }
                 }
             }
@@ -593,11 +634,11 @@ define([
             for (i = 0; i < arr.length; i++) {
                 isArray = this.isArray(arr[i]);
 
-                if (!isArray && arr[i] !== '') {
+                if (!isArray && arr[i] !== "") {
                     ret[j] = arr[i];
                     j++;
                 } else if (isArray && arr[i].length !== 0) {
-                    ret[j] = (arr[i].slice(0));
+                    ret[j] = arr[i].slice(0);
                     j++;
                 }
             }
@@ -725,17 +766,17 @@ define([
             value = +value;
             exp = +exp;
             // If the value is not a number or the exp is not an integer...
-            if (isNaN(value) || !(typeof exp === 'number' && exp % 1 === 0)) {
+            if (isNaN(value) || !(typeof exp === "number" && exp % 1 === 0)) {
                 return NaN;
             }
 
             // Shift
-            value = value.toString().split('e');
-            value = Math[type](+(value[0] + 'e' + (value[1] ? (+value[1] - exp) : -exp)));
+            value = value.toString().split("e");
+            value = Math[type](+(value[0] + "e" + (value[1] ? +value[1] - exp : -exp)));
 
             // Shift back
-            value = value.toString().split('e');
-            return +(value[0] + 'e' + (value[1] ? (+value[1] + exp) : exp));
+            value = value.toString().split("e");
+            return +(value[0] + "e" + (value[1] ? +value[1] + exp : exp));
         },
 
         /**
@@ -749,7 +790,7 @@ define([
          * @private
          */
         _round10: function (value, exp) {
-            return this._decimalAdjust('round', value, exp);
+            return this._decimalAdjust("round", value, exp);
         },
 
         /**
@@ -763,7 +804,7 @@ define([
          * @private
          */
         _floor10: function (value, exp) {
-            return this._decimalAdjust('floor', value, exp);
+            return this._decimalAdjust("floor", value, exp);
         },
 
         /**
@@ -777,7 +818,7 @@ define([
          * @private
          */
         _ceil10: function (value, exp) {
-            return this._decimalAdjust('ceil', value, exp);
+            return this._decimalAdjust("ceil", value, exp);
         },
 
         /**
@@ -825,7 +866,8 @@ define([
          * @returns {Array} All keys of the given object.
          */
         keys: function (object, onlyOwn) {
-            var keys = [], property;
+            var keys = [],
+                property;
 
             // the caller decides if we use hasOwnProperty
             /*jslint forin:true*/
@@ -867,7 +909,9 @@ define([
          */
         cloneAndCopy: function (obj, obj2) {
             var r,
-                cObj = function () { return undefined; };
+                cObj = function () {
+                    return undefined;
+                };
 
             cObj.prototype = obj;
 
@@ -903,13 +947,13 @@ define([
                         }
 
                         for (j = 0; j < obj2[i].length; j++) {
-                            if (typeof obj2[i][j] === 'object') {
+                            if (typeof obj2[i][j] === "object") {
                                 obj1[i][j] = this.merge(obj1[i][j], obj2[i][j]);
                             } else {
                                 obj1[i][j] = obj2[i][j];
                             }
                         }
-                    } else if (typeof obj2[i] === 'object') {
+                    } else if (typeof obj2[i] === "object") {
                         if (!obj1[i]) {
                             obj1[i] = {};
                         }
@@ -937,7 +981,6 @@ define([
             var c, i, prop, i2;
 
             toLower = toLower || false;
-
             if (typeof obj !== 'object' || obj === null) {
                 return obj;
             }
@@ -947,7 +990,7 @@ define([
                 c = [];
                 for (i = 0; i < obj.length; i++) {
                     prop = obj[i];
-                    if (typeof prop === 'object') {
+                    if (typeof prop === "object") {
                         // We certainly do not want to recurse into a JSXGraph object.
                         // This would for sure result in an infinite recursion.
                         // As alternative we copy the id of the object.
@@ -966,7 +1009,7 @@ define([
                     if (obj.hasOwnProperty(i)) {
                         i2 = toLower ? i.toLowerCase() : i;
                         prop = obj[i];
-                        if (prop !== null && typeof prop === 'object') {
+                        if (prop !== null && typeof prop === "object") {
                             if (this.exists(prop.board)) {
                                 c[i2] = prop.id;
                             } else {
@@ -983,7 +1026,7 @@ define([
                         i2 = toLower ? i.toLowerCase() : i;
 
                         prop = obj2[i];
-                        if (typeof prop === 'object') {
+                        if (typeof prop === "object") {
                             if (this.isArray(prop) || !this.exists(c[i2])) {
                                 c[i2] = this.deepCopy(prop);
                             } else {
@@ -999,6 +1042,50 @@ define([
             return c;
         },
 
+        /**
+         * In-place (deep) merging of attributes. Allows attributes like `{shadow: {enabled: true...}}`
+         *
+         * @param {Object} attr Object with attributes - usually containing default options
+         * @param {Object} special Special option values which overwrite (recursively) the default options
+         * @param {Boolean} [toLower=true] If true the keys are convert to lower case.
+         *
+         * @private
+         */
+        mergeAttr: function (attr, special, toLower) {
+            var e, e2, o;
+
+            toLower = toLower || true;
+
+            for (e in special) {
+                if (special.hasOwnProperty(e)) {
+                    e2 = (toLower) ? e.toLowerCase(): e;
+
+                    o = special[e];
+                    if (this.isObject(o) && o !== null &&
+                        // Do not recurse into a document object or a JSXGraph object
+                        !this.isDocumentOrFragment(o) && !this.exists(o.board) &&
+                        // Do not recurse if a string is provided as "new String(...)"
+                        typeof o.valueOf() !== 'string') {
+                        if (attr[e2] === undefined || attr[e2] === null || !this.isObject(attr[e2])) {
+                            // The last test handles the case:
+                            //   attr.draft = false;
+                            //   special.draft = { strokewidth: 4}
+                            attr[e2] = {};
+                        }
+                        this.mergeAttr(attr[e2], o, toLower);
+                    } else {
+                        // Flat copy
+                        // This is also used in the cases
+                        //   attr.shadow = { enabled: true ...}
+                        //   special.shadow = false;
+                        // and
+                        //   special.anchor is a JSXGraph element
+                        attr[e2] = o;
+                    }
+                }
+            }
+        },
+
         /**
          * Generates an attributes object that is filled with default values from the Options object
          * and overwritten by the user specified attributes.
@@ -1008,22 +1095,26 @@ define([
          * @returns {Object} The resulting attributes object
          */
         copyAttributes: function (attributes, options, s) {
-            var a, i, len, o, isAvail,
+            var a,
+                i,
+                len,
+                o,
+                isAvail,
                 primitives = {
-                    'circle': 1,
-                    'curve': 1,
-                    'image': 1,
-                    'line': 1,
-                    'point': 1,
-                    'polygon': 1,
-                    'text': 1,
-                    'ticks': 1,
-                    'integral': 1
+                    circle: 1,
+                    curve: 1,
+                    image: 1,
+                    line: 1,
+                    point: 1,
+                    polygon: 1,
+                    text: 1,
+                    ticks: 1,
+                    integral: 1
                 };
 
             len = arguments.length;
             if (len < 3 || primitives[s]) {
-                // default options from Options.elements
+                // Default options from Options.elements
                 a = JXG.deepCopy(options.elements, null, true);
             } else {
                 a = {};
@@ -1034,7 +1125,8 @@ define([
                 a.layer = options.layer[s];
             }
 
-            // default options from specific elements
+            // Default options from the specific element like 'line' in
+            // copyAttribute(attributes, board.options, 'line')
             o = options;
             isAvail = true;
             for (i = 2; i < len; i++) {
@@ -1049,7 +1141,11 @@ define([
                 a = JXG.deepCopy(a, o, true);
             }
 
-            // options from attributes
+            // Merge the specific options given in the parameter 'attributes'
+            // into the default options.
+            // Additionally, we step into a subelement of attribute like line.point1 in case it is supplied as in
+            // copyAttribute(attributes, board.options, 'line', 'point1')
+            // In this case we would merge attributes.point1 into the global line.point1 attributes.
             o = (typeof attributes === 'object') ? attributes : {};
             isAvail = true;
             for (i = 3; i < len; i++) {
@@ -1061,10 +1157,10 @@ define([
                 }
             }
             if (isAvail) {
-                this.extend(a, o, null, true);
+                this.mergeAttr(a, o, true);
             }
 
-            if (arguments[2] === 'board') {
+            if (arguments[2] === "board") {
                 // For board attributes we are done now.
                 return a;
             }
@@ -1132,7 +1228,7 @@ define([
             }
 
             switch (typeof obj) {
-                case 'object':
+                case "object":
                     if (obj) {
                         list = [];
 
@@ -1141,7 +1237,7 @@ define([
                                 list.push(JXG.toJSON(obj[i], noquote));
                             }
 
-                            return '[' + list.join(',') + ']';
+                            return "[" + list.join(",") + "]";
                         }
 
                         for (prop in obj) {
@@ -1149,28 +1245,28 @@ define([
                                 try {
                                     val = JXG.toJSON(obj[prop], noquote);
                                 } catch (e2) {
-                                    val = '';
+                                    val = "";
                                 }
 
                                 if (noquote) {
-                                    list.push(prop + ':' + val);
+                                    list.push(prop + ":" + val);
                                 } else {
                                     list.push('"' + prop + '":' + val);
                                 }
                             }
                         }
 
-                        return '{' + list.join(',') + '} ';
+                        return "{" + list.join(",") + "} ";
                     }
-                    return 'null';
-                case 'string':
-                    return '\'' + obj.replace(/(["'])/g, '\\$1') + '\'';
-                case 'number':
-                case 'boolean':
+                    return "null";
+                case "string":
+                    return "'" + obj.replace(/(["'])/g, "\\$1") + "'";
+                case "number":
+                case "boolean":
                     return obj.toString();
             }
 
-            return '0';
+            return "0";
         },
 
         /**
@@ -1180,20 +1276,20 @@ define([
          */
         clearVisPropOld: function (el) {
             el.visPropOld = {
-                cssclass: '',
-                cssdefaultstyle: '',
-                cssstyle: '',
-                fillcolor: '',
-                fillopacity: '',
+                cssclass: "",
+                cssdefaultstyle: "",
+                cssstyle: "",
+                fillcolor: "",
+                fillopacity: "",
                 firstarrow: false,
                 fontsize: -1,
                 lastarrow: false,
                 left: -100000,
-                linecap: '',
+                linecap: "",
                 shadow: false,
-                strokecolor: '',
-                strokeopacity: '',
-                strokewidth: '',
+                strokecolor: "",
+                strokeopacity: "",
+                strokewidth: "",
                 tabindex: -100000,
                 transitionduration: 0,
                 top: -100000,
@@ -1229,7 +1325,7 @@ define([
          * @returns {String}
          */
         escapeHTML: function (str) {
-            return str.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;');
+            return str.replace(/&/g, "&amp;").replace(/</g, "&lt;").replace(/>/g, "&gt;");
         },
 
         /**
@@ -1241,7 +1337,11 @@ define([
         unescapeHTML: function (str) {
             // This regex is NOT insecure. We are replacing everything found with ''
             /*jslint regexp:true*/
-            return str.replace(/<\/?[^>]+>/gi, '').replace(/&amp;/g, '&').replace(/&lt;/g, '<').replace(/&gt;/g, '>');
+            return str
+                .replace(/<\/?[^>]+>/gi, "")
+                .replace(/&amp;/g, "&")
+                .replace(/&lt;/g, "<")
+                .replace(/&gt;/g, ">");
         },
 
         /**
@@ -1259,15 +1359,15 @@ define([
          * @returns {String}
          */
         trimNumber: function (str) {
-            str = str.replace(/^0+/, '');
-            str = str.replace(/0+$/, '');
+            str = str.replace(/^0+/, "");
+            str = str.replace(/0+$/, "");
 
-            if (str[str.length - 1] === '.' || str[str.length - 1] === ',') {
+            if (str[str.length - 1] === "." || str[str.length - 1] === ",") {
                 str = str.slice(0, -1);
             }
 
-            if (str[0] === '.' || str[0] === ',') {
-                str = '0' + str;
+            if (str[0] === "." || str[0] === ",") {
+                str = "0" + str;
             }
 
             return str;
@@ -1280,11 +1380,17 @@ define([
          * @returns {Array}
          */
         filterElements: function (list, filter) {
-            var i, f, item, flower, value, visPropValue, pass,
+            var i,
+                f,
+                item,
+                flower,
+                value,
+                visPropValue,
+                pass,
                 l = list.length,
                 result = [];
 
-            if (typeof filter !== 'function' && typeof filter !== 'object') {
+            if (typeof filter !== "function" && typeof filter !== "object") {
                 return result;
             }
 
@@ -1292,27 +1398,27 @@ define([
                 pass = true;
                 item = list[i];
 
-                if (typeof filter === 'object') {
+                if (typeof filter === "object") {
                     for (f in filter) {
                         if (filter.hasOwnProperty(f)) {
                             flower = f.toLowerCase();
 
-                            if (typeof item[f] === 'function') {
+                            if (typeof item[f] === "function") {
                                 value = item[f]();
                             } else {
                                 value = item[f];
                             }
 
-                            if (item.visProp && typeof item.visProp[flower] === 'function') {
+                            if (item.visProp && typeof item.visProp[flower] === "function") {
                                 visPropValue = item.visProp[flower]();
                             } else {
                                 visPropValue = item.visProp && item.visProp[flower];
                             }
 
-                            if (typeof filter[f] === 'function') {
+                            if (typeof filter[f] === "function") {
                                 pass = filter[f](value) || filter[f](visPropValue);
                             } else {
-                                pass = (value === filter[f] || visPropValue === filter[f]);
+                                pass = value === filter[f] || visPropValue === filter[f];
                             }
 
                             if (!pass) {
@@ -1320,7 +1426,7 @@ define([
                             }
                         }
                     }
-                } else if (typeof filter === 'function') {
+                } else if (typeof filter === "function") {
                     pass = filter(item);
                 }
 
@@ -1342,7 +1448,7 @@ define([
             // str = str.replace(/\s+$/, '');
             //
             // return str;
-            return str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, '');
+            return str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, "");
         },
 
         /**
@@ -1352,12 +1458,20 @@ define([
          * @returns {String} Sanitized string
          */
         sanitizeHTML: function (str, caja) {
-            if (typeof html_sanitize === 'function' && caja) {
-                return html_sanitize(str, function () { return undefined; }, function (id) { return id; });
+            if (typeof html_sanitize === "function" && caja) {
+                return html_sanitize(
+                    str,
+                    function () {
+                        return undefined;
+                    },
+                    function (id) {
+                        return id;
+                    }
+                );
             }
 
-            if (str && typeof str === 'string') {
-                str = str.replace(/</g, '&lt;').replace(/>/g, '&gt;');
+            if (str && typeof str === "string") {
+                str = str.replace(/</g, "&lt;").replace(/>/g, "&gt;");
             }
 
             return str;
@@ -1369,13 +1483,13 @@ define([
          * @returns {*} s.Value() if s is an element of type slider, s otherwise
          */
         evalSlider: function (s) {
-            if (s && s.type === Const.OBJECT_TYPE_GLIDER && typeof s.Value === 'function') {
+            if (s && s.type === Const.OBJECT_TYPE_GLIDER && typeof s.Value === "function") {
                 return s.Value();
             }
 
             return s;
         }
-    });
+    }
+);
 
-    return JXG;
-});
+export default JXG;
