@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2023
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -25,16 +25,17 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
 
 describe("Test JXG util functions", function () {
     var board;
 
-    document.getElementsByTagName('body')[0].innerHTML = '<div id="jxgbox" style="width: 100px; height: 100px;"></div>';
-    board = JXG.JSXGraph.initBoard('jxgbox', {
-        renderer: 'no',
+    document.getElementsByTagName("body")[0].innerHTML =
+        '<div id="jxgbox" style="width: 100px; height: 100px;"></div>';
+    board = JXG.JSXGraph.initBoard("jxgbox", {
+        renderer: "no",
         axis: false,
         grid: false,
         boundingbox: [-5, 5, 5, -5],
@@ -44,20 +45,20 @@ describe("Test JXG util functions", function () {
 
     it("Extend", function () {
         var e = {
-            foo: 1,
-            bar: 'string',
-            dr: {
-                foo: 3
-            }
-        },
+                foo: 1,
+                bar: "string",
+                dr: {
+                    foo: 3
+                }
+            },
             o = {
                 old: 3,
-                bar: 'nostring'
+                bar: "nostring"
             };
 
         JXG.extend(o, e);
         expect(o.old).toEqual(3);
-        expect(o.bar).toEqual('string');
+        expect(o.bar).toEqual("string");
         expect(o.foo).toEqual(1);
         o.dr.foo = 4;
         expect(e.dr.foo).toEqual(4);
@@ -65,10 +66,13 @@ describe("Test JXG util functions", function () {
 
     it("Shortcut", function () {
         var o = {
-            justAFunction: function () { o.justAFunction.called = true; return arguments; }
+            justAFunction: function () {
+                o.justAFunction.called = true;
+                return arguments;
+            }
         };
 
-        o.shortcut = JXG.shortcut(o, 'justAFunction');
+        o.shortcut = JXG.shortcut(o, "justAFunction");
         expect(o.shortcut).toBeInstanceOf(Function);
 
         o.shortcut();
@@ -79,26 +83,26 @@ describe("Test JXG util functions", function () {
     });
 
     it("isString", function () {
-        expect(JXG.isString('string')).toBeTrue();
+        expect(JXG.isString("string")).toBeTrue();
         expect(JXG.isString(3)).toBeFalse();
         expect(JXG.isString({ f: 1 })).toBeFalse();
         expect(JXG.isString(new String())).toBeFalse();
-        expect(JXG.isString(function () { })).toBeFalse();
+        expect(JXG.isString(function () {})).toBeFalse();
     });
 
     it("isNumber", function () {
         expect(JXG.isNumber(4.5)).toBeTrue();
         expect(JXG.isNumber(4)).toBeTrue();
-        expect(JXG.isNumber('string')).toBeFalse();
+        expect(JXG.isNumber("string")).toBeFalse();
         expect(JXG.isString({ f: 1 })).toBeFalse();
         expect(JXG.isString(new Number())).toBeFalse();
-        expect(JXG.isString(function () { })).toBeFalse();
+        expect(JXG.isString(function () {})).toBeFalse();
     });
 
     it("isFunction", function () {
-        expect(JXG.isFunction(function () { })).toBeTrue();
+        expect(JXG.isFunction(function () {})).toBeTrue();
         expect(JXG.isFunction(new Function())).toBeTrue();
-        expect(JXG.isFunction('string')).toBeFalse();
+        expect(JXG.isFunction("string")).toBeFalse();
         expect(JXG.isFunction(3)).toBeFalse();
         expect(JXG.isFunction({ f: 1 })).toBeFalse();
     });
@@ -106,15 +110,15 @@ describe("Test JXG util functions", function () {
     it("isArray", function () {
         expect(JXG.isArray([1])).toBeTrue();
         expect(JXG.isArray(new Array())).toBeTrue();
-        expect(JXG.isArray('string')).toBeFalse();
+        expect(JXG.isArray("string")).toBeFalse();
         expect(JXG.isArray(3)).toBeFalse();
         expect(JXG.isArray({ f: 1 })).toBeFalse();
     });
 
     it("exists", function () {
-        var o, 
-            b = '1',
-            x = {a: 1};
+        var o,
+            b = "1",
+            x = { a: 1 };
         expect(JXG.exists(b)).toBeTrue();
         expect(JXG.exists(o)).toBeFalse();
         expect(JXG.exists(x.a)).toBeTrue();
@@ -122,35 +126,36 @@ describe("Test JXG util functions", function () {
     });
 
     it("str2Bool", function () {
-        expect(JXG.str2Bool('true')).toBeTrue();
-        expect(JXG.str2Bool('false')).toBeFalse();
+        expect(JXG.str2Bool("true")).toBeTrue();
+        expect(JXG.str2Bool("false")).toBeFalse();
         expect(JXG.str2Bool(true)).toBeTrue();
         expect(JXG.str2Bool(false)).toBeFalse();
     });
 
-
     it("deepCopy", function () {
         var o = {
-                str: 'string',
+                str: "string",
                 num: 123,
-                arr: [1, 'str', ['inner array']],
+                arr: [1, "str", ["inner array"]],
                 obj: {
                     subprop: 2
                 },
                 funCalled: 0,
-                fun: function () { this.funCalled += 1; },
-                name: 'test'
+                fun: function () {
+                    this.funCalled += 1;
+                },
+                name: "test"
             },
             copy;
 
         copy = JXG.deepCopy(o);
 
-        expect(copy.str).toEqual('string');
+        expect(copy.str).toEqual("string");
         expect(copy.num).toEqual(123);
-        expect(copy.arr).toEqual([1, 'str', ['inner array']]);
+        expect(copy.arr).toEqual([1, "str", ["inner array"]]);
         expect(copy.obj.subprop).toEqual(2);
         expect(copy.fun).toBeInstanceOf(Function);
-        expect(copy.name).toEqual('test');
+        expect(copy.name).toEqual("test");
 
         copy.fun();
         expect(copy.funCalled).toEqual(1);
@@ -158,7 +163,7 @@ describe("Test JXG util functions", function () {
 
     it("deepCopyMerge", function () {
         var o1 = {
-                color: 'abc',
+                color: "abc",
                 arr: [1, 2, 3],
                 num: 10,
                 subo: {
@@ -166,27 +171,24 @@ describe("Test JXG util functions", function () {
                 }
             },
             o2 = {
-                color: 'def',
+                color: "def",
                 arr: [4, 5, 6],
                 o: {
                     subprop: 12
                 },
-                name: 'test',
-                subo: {
-
-                }
+                name: "test",
+                subo: {}
             },
             copy;
 
         copy = JXG.deepCopy(o1, o2);
-        expect(copy.color).toEqual('def');
+        expect(copy.color).toEqual("def");
         expect(copy.arr).toEqual([4, 5, 6]);
         expect(copy.o.subprop).toEqual(12);
         expect(copy.num).toEqual(10);
         expect(copy.subo.foo).toEqual(42);
-        expect(copy.name).toEqual('test');
+        expect(copy.name).toEqual("test");
     });
-
 });
 
 /*
