@@ -1,5 +1,5 @@
 /*
-    Copyright 2008-2022
+    Copyright 2008-2023
         Matthias Ehmann,
         Michael Gerhaeuser,
         Carsten Miller,
@@ -25,42 +25,51 @@
     GNU Lesser General Public License for more details.
 
     You should have received a copy of the GNU Lesser General Public License and
-    the MIT License along with JSXGraph. If not, see <http://www.gnu.org/licenses/>
-    and <http://opensource.org/licenses/MIT/>.
+    the MIT License along with JSXGraph. If not, see <https://www.gnu.org/licenses/>
+    and <https://opensource.org/licenses/MIT/>.
  */
 
 describe("Test slider", function () {
     var board, slider;
 
-    document.getElementsByTagName('body')[0].innerHTML = '<div id="jxgbox" style="width: 100px; height: 100px;"></div>';
-    board = JXG.JSXGraph.initBoard('jxgbox', {
-        renderer: 'no',
+    document.getElementsByTagName("body")[0].innerHTML =
+        '<div id="jxgbox" style="width: 100px; height: 100px;"></div>';
+    board = JXG.JSXGraph.initBoard("jxgbox", {
+        renderer: "no",
         axis: false,
         grid: false,
         boundingbox: [-5, 5, 5, -5],
         showCopyright: false,
         showNavigation: false
     });
-    slider = board.create('slider', [[0, 0], [1, 0], [0, 5, 10]], {
-        id: '_glider',
-        withLabel: true,
-        name: 'S',
-        point1: {
-            id: '_point1'
-        },
-        point2: {
-            id: '_point2'
-        },
-        baseline: {
-            id: '_baseline'
-        },
-        highline: {
-            id: '_highline'
-        },
-        label: {
-            id: '_label'
+    slider = board.create(
+        "slider",
+        [
+            [0, 0],
+            [1, 0],
+            [0, 5, 10]
+        ],
+        {
+            id: "_glider",
+            withLabel: true,
+            name: "S",
+            point1: {
+                id: "_point1"
+            },
+            point2: {
+                id: "_point2"
+            },
+            baseline: {
+                id: "_baseline"
+            },
+            highline: {
+                id: "_highline"
+            },
+            label: {
+                id: "_label"
+            }
         }
-    });
+    );
 
     it("Create slider", function () {
         expect(slider.type).toEqual(JXG.OBJECT_TYPE_GLIDER);
@@ -73,11 +82,11 @@ describe("Test slider", function () {
     });
 
     it("Slider ids", function () {
-        expect(slider.id).toEqual('_glider');
-        expect(slider.point1.id).toEqual('_point1');
-        expect(slider.point2.id).toEqual('_point2');
-        expect(slider.baseline.id).toEqual('_baseline');
-        expect(slider.highline.id).toEqual('_highline');
-        expect(slider.label.id).toEqual('_label');
+        expect(slider.id).toEqual("_glider");
+        expect(slider.point1.id).toEqual("_point1");
+        expect(slider.point2.id).toEqual("_point2");
+        expect(slider.baseline.id).toEqual("_baseline");
+        expect(slider.highline.id).toEqual("_highline");
+        expect(slider.label.id).toEqual("_label");
     });
 });
